@@ -1584,7 +1584,9 @@ bool DatabaseManager::deleteTarget(Target * target)
 
 bool DatabaseManager::_deleteTarget(int idTarget)
 {
-    bool ret = false;
+	qDebug () << "going to delete " << idTarget;
+
+    bool ret = true;
 	if (db.isOpen()) {
 		QSqlQuery query (db);
 
@@ -1596,9 +1598,8 @@ bool DatabaseManager::_deleteTarget(int idTarget)
 		if (ret) {
 			ret = query.prepare("delete from targets where id=:code");
 			if (ret) {
-				//qDebug () << "DELETE " << target->id;
-
-                                query.bindValue(":code", idTarget);
+				qDebug () << "DELETE " << idTarget;
+                query.bindValue(":code", idTarget);
 				ret = query.exec();
 			}
 		}
