@@ -11,7 +11,7 @@
 #include "CreateFieldDialog.h"
 #include "ImageViewer.h"
 #include "QLabelImage.h"
-
+#include "CreatePasswordDialog.h"
 class eWallet;
 
 
@@ -70,7 +70,8 @@ private:
 
 	QGridLayout * componentLayout;
 	QPointer<CreateFieldDialog> createFieldDlg;
-	//QPointer<ImageViewer> viewerWindow;
+	QSignalMapper * signalMapper;
+	QPointer<CreatePasswordDialog> createPasswordDlg;
 
 public slots:
 	void saveTarget();
@@ -115,6 +116,7 @@ public slots:
 
 	void emitCommitData (int);
 	void clickPass (QWidget *);
+	void passGen (QWidget *);
 	void modifyFields ();
 
 signals:
@@ -139,4 +141,12 @@ public:
 	}
 };
 
+class ButtonInfo2: public QObjectUserData {
+public:
+	QLineEdit * nameLineEdit;
+
+	ButtonInfo2 (QLineEdit * nameLineEdit) {
+		this->nameLineEdit = nameLineEdit;
+	}
+};
 #endif // DETAIL_H
